@@ -29,9 +29,11 @@ using namespace std;
 
 struct unique_LU
 {
-	unsigned int id;
+	int id;
 	wstring wordform;
 	wstring tl_wordform;
+  wstring sl_lemma;
+  wstring tl_lemma;
 	vector<wstring> pos_tags;
 	vector<wstring> properties;
 };
@@ -42,11 +44,19 @@ struct antecedent
 	int score;
 };
 
+struct parameter_return
+{
+	int found;
+	wstring parameter_name;
+};
+
 int contains(vector<wstring> tags, wstring tag);
 int contains_any(vector<wstring> tags, vector<wstring> candidates);
+void toLower(basic_string<wchar_t>& s);
 
-int check_acceptable_tags(vector<wstring> input_tags, acceptable_tags check_tags);
+int check_acceptable_tags(vector<wstring> input_tags, wstring input_sl_lemma, acceptable_tags check_tags);
+parameter_return check_pattern_name(vector<wstring> input_tags, wstring input_sl_lemma, unordered_map<wstring, acceptable_tags> parameter_names);
 
 deque< vector<unique_LU> > add_properties(deque< vector<unique_LU> > context, ParseArx arx_file);
 
-#endif
\ No newline at end of file
+#endif
